@@ -1,15 +1,10 @@
-import dns.resolver
-
-import os
 import ipaddress
-import shutil
-from typing import Any, Dict, List
+import os
+from typing import Any
+from typing import Dict
+from typing import List
 
-
-def __virtual__(hub):
-    if shutil.which("scutil"):
-        return False, "Systems with scutil don't read resolv.conf files"
-    return True
+import dns.resolver
 
 
 async def _cidr_to_ipv4_netmask(cidr_bits: str or int) -> str:
@@ -31,7 +26,7 @@ async def _cidr_to_ipv4_netmask(cidr_bits: str or int) -> str:
             netmask += "255"
             cidr_bits -= 8
         else:
-            netmask += "{0:d}".format(256 - (2 ** (8 - cidr_bits)))
+            netmask += f"{256 - (2 ** (8 - cidr_bits)):d}"
             cidr_bits = 0
     return netmask
 
@@ -119,6 +114,9 @@ async def load_dns(hub):
     """
     Parse the resolver configuration file
     """
+    if "dns" in hub.grains.GRAINS:
+        return
+
     resolv = dns.resolver.Resolver(configure=False)
 
     # Read known resolv.conf files
