@@ -22,6 +22,8 @@ async def run(
     umask: str = None,
     timeout: int or float = None,
     render_pipe: str = None,
+    is_string_output: bool = False,
+    success_retcodes: List[int] = None,
     **kwargs,
 ) -> Dict[str, Any]:
     """
@@ -37,6 +39,8 @@ async def run(
     :param umask: The umask (in octal) to use when running the command.
     :param timeout: If the command has not terminated after timeout seconds, send the subprocess sigterm, and if sigterm is ignored, follow up with sigkill
     :param render_pipe: The render pipe to use on the output
+    :param is_string_output: Give the output in string format irrespective of format the command executed returns
+    :param success_retcodes: The result will be True if the command's return code is in this list. Defaults to [0].
     :param kwargs: kwargs that will be forwarded to subprocess.Popen
 
     .. code-block:: sls
@@ -91,14 +95,15 @@ async def run(
         return ret
 
     if ctx["test"]:
-        ret["comment"] = f'Command "{cmd}" would have been executed'
-        return ret
+        ret["comment"] = f"The cmd.run state runs even when ctx.test is enabled"
 
     cmd_ret = await hub.exec.cmd.run(
         cmd=cmd,
         timeout=timeout,
         python_shell=True,
         render_pipe=render_pipe,
+        is_string_output=is_string_output,
+        success_retcodes=success_retcodes,
         **cmd_kwargs,
     )
 
